@@ -35,6 +35,7 @@
 #include "Enumeration.h"
 #include "ColorScheme.h"
 #include "ColorSchemeEditor.h"
+#include "KeyboardTranslatorManager.h"
 
 class QAbstractButton;
 class QItemSelectionModel;
@@ -165,6 +166,7 @@ private Q_SLOTS:
     void newKeyBinding();
     void keyBindingSelected();
     void removeKeyBinding();
+    void resetKeyBindings();
 
     // mouse page
     void toggleUnderlineFiles(bool enable);
@@ -178,6 +180,7 @@ private Q_SLOTS:
     void toggleTrimTrailingSpacesInSelectedText(bool);
     void pasteFromX11Selection();
     void pasteFromClipboard();
+    void toggleAlternateScrolling(bool enable);
 
     void TripleClickModeChanged(int);
     void wordCharactersChanged(const QString &);
@@ -219,12 +222,18 @@ private:
     void updateColorSchemeList(const QString &selectedColorSchemeName = QString());
 
     void updateColorSchemeButtons();
-    void updateKeyBindingsList(bool selectCurrentTranslator = false);
+
+    // Convenience method
+    KeyboardTranslatorManager *_keyManager = KeyboardTranslatorManager::instance();
+
+    // Updates the key bindings list widget on the Keyboard tab and selects
+    // @p selectTranslatorName
+    void updateKeyBindingsList(const QString &selectTranslatorName = QString());
     void updateKeyBindingsButtons();
+    void showKeyBindingEditor(bool isNewTranslator);
 
     void showColorSchemeEditor(bool isNewScheme);
     void closeColorSchemeEditor();
-    void showKeyBindingEditor(bool isNewTranslator);
 
     void preview(int property, const QVariant &value);
     void delayedPreview(int property, const QVariant &value);
@@ -255,13 +264,13 @@ private:
         int value;
         const char *slot;
     };
-    void setupRadio(RadioOption *possibilities, int actual);
+    void setupRadio(const QVector<RadioOption>& possibilities, int actual);
     struct BooleanOption {
         QAbstractButton *button;
         Profile::Property property;
         const char *slot;
     };
-    void setupCheckBoxes(BooleanOption *options, const Profile::Ptr profile);
+    void setupCheckBoxes(const QVector<BooleanOption>& options, const Profile::Ptr profile);
 
     // returns false if:
     // - the profile name is empty
