@@ -27,6 +27,9 @@
 #include <QTimer>
 #include <QToolButton>
 #include <QMenu>
+#include <QApplication>
+#include <QPaintEvent>
+#include <QPainter>
 
 // KDE
 #include <KColorScheme>
@@ -45,9 +48,11 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *aParent) :
     _reverseSearch(nullptr),
     _findNextButton(nullptr),
     _findPreviousButton(nullptr),
-    _searchFromButton(nullptr)
+    _searchFromButton(nullptr),
+    _searchTimer(nullptr)
 {
-    auto barLayout = new QHBoxLayout(this);
+    setPalette(qApp->palette());
+    setAutoFillBackground(true);
 
     auto closeButton = new QToolButton(this);
     closeButton->setObjectName(QStringLiteral("close-button"));
@@ -56,13 +61,17 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *aParent) :
     closeButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     connect(closeButton, &QToolButton::clicked, this, &Konsole::IncrementalSearchBar::closeClicked);
 
-    QLabel *findLabel = new QLabel(i18nc("@label:textbox", "Find:"), this);
     _searchEdit = new QLineEdit(this);
     _searchEdit->setClearButtonEnabled(true);
     _searchEdit->installEventFilter(this);
+    _searchEdit->setPlaceholderText(i18nc("@label:textbox", "Find..."));
     _searchEdit->setObjectName(QStringLiteral("search-edit"));
     _searchEdit->setToolTip(i18nc("@info:tooltip", "Enter the text to search for here"));
+    _searchEdit->setCursor(Qt::IBeamCursor);
+    _searchEdit->setStyleSheet(QString());
+    _searchEdit->setFont(QApplication::font());
 
+    setCursor(Qt::ArrowCursor);
     // text box may be a minimum of 6 characters wide and a maximum of 10 characters wide
     // (since the maxWidth metric is used here, more characters probably will fit in than 6
     //  and 10)
@@ -82,42 +91,38 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *aParent) :
     _findNextButton = new QToolButton(this);
     _findNextButton->setObjectName(QStringLiteral("find-next-button"));
     _findNextButton->setText(i18nc("@action:button Go to the next phrase", "Next"));
-    _findNextButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    _findNextButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+    _findNextButton->setAutoRaise(true);
     _findNextButton->setToolTip(i18nc("@info:tooltip",
                                       "Find the next match for the current search phrase"));
     connect(_findNextButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::findNextClicked);
 
     _findPreviousButton = new QToolButton(this);
+    _findPreviousButton->setAutoRaise(true);
     _findPreviousButton->setObjectName(QStringLiteral("find-previous-button"));
     _findPreviousButton->setText(i18nc("@action:button Go to the previous phrase", "Previous"));
-    _findPreviousButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    _findPreviousButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
     _findPreviousButton->setToolTip(i18nc("@info:tooltip",
                                           "Find the previous match for the current search phrase"));
     connect(_findPreviousButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::findPreviousClicked);
 
     _searchFromButton = new QToolButton(this);
+    _searchFromButton->setAutoRaise(true);
+
     _searchFromButton->setObjectName(QStringLiteral("search-from-button"));
     connect(_searchFromButton, &QToolButton::clicked, this,
             &Konsole::IncrementalSearchBar::searchFromClicked);
 
     auto optionsButton = new QToolButton(this);
     optionsButton->setObjectName(QStringLiteral("find-options-button"));
-    optionsButton->setText(i18nc("@action:button Display options menu", "Options"));
     optionsButton->setCheckable(false);
     optionsButton->setPopupMode(QToolButton::InstantPopup);
-    optionsButton->setArrowType(Qt::DownArrow);
-    optionsButton->setToolButtonStyle(Qt::ToolButtonTextOnly);
+    optionsButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
     optionsButton->setToolTip(i18nc("@info:tooltip", "Display the options menu"));
-
-    barLayout->addWidget(closeButton);
-    barLayout->addWidget(findLabel);
-    barLayout->addWidget(_searchEdit);
-    barLayout->addWidget(_findNextButton);
-    barLayout->addWidget(_findPreviousButton);
-    barLayout->addWidget(_searchFromButton);
-    barLayout->addWidget(optionsButton);
+    optionsButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
+    optionsButton->setAutoRaise(true);
 
     // Fill the options menu
     auto optionsMenu = new QMenu(this);
@@ -150,11 +155,19 @@ IncrementalSearchBar::IncrementalSearchBar(QWidget *aParent) :
     updateButtonsAccordingToReverseSearchSetting();
     setOptions();
 
-    barLayout->addStretch();
-
+    auto barLayout = new QHBoxLayout(this);
+    barLayout->addWidget(_searchEdit);
+    barLayout->addWidget(_findNextButton);
+    barLayout->addWidget(_findPreviousButton);
+    barLayout->addWidget(_searchFromButton);
+    barLayout->addWidget(optionsButton);
+    barLayout->addWidget(closeButton);
     barLayout->setContentsMargins(4, 4, 4, 4);
+    barLayout->setSpacing(0);
 
     setLayout(barLayout);
+    adjustSize();
+    clearLineEdit();
 }
 
 void IncrementalSearchBar::notifySearchChanged()
@@ -166,17 +179,17 @@ void IncrementalSearchBar::updateButtonsAccordingToReverseSearchSetting()
 {
     Q_ASSERT(_reverseSearch);
     if (_reverseSearch->isChecked()) {
-        _searchFromButton->setText(i18nc("@action:button Search from bottom", "From bottom"));
         _searchFromButton->setToolTip(i18nc("@info:tooltip",
                                             "Search for the current search phrase from the bottom"));
-        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up-search")));
-        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down-search")));
+        _searchFromButton->setIcon(QIcon::fromTheme(QStringLiteral("go-bottom")));
+        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
+        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     } else {
-        _searchFromButton->setText(i18nc("@action:button Search from top", "From top"));
         _searchFromButton->setToolTip(i18nc("@info:tooltip",
                                             "Search for the current search phrase from the top"));
-        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down-search")));
-        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up-search")));
+        _searchFromButton->setIcon(QIcon::fromTheme(QStringLiteral("go-top")));
+        _findNextButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
+        _findPreviousButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     }
 }
 
@@ -194,50 +207,52 @@ void IncrementalSearchBar::setSearchText(const QString &text)
 
 bool IncrementalSearchBar::eventFilter(QObject *watched, QEvent *event)
 {
-    if (watched == _searchEdit) {
-        if (event->type() == QEvent::KeyPress) {
-            QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+    if ((event->type() != QEvent::KeyPress) || watched != _searchEdit)
+        return QWidget::eventFilter(watched, event);
 
-            if (keyEvent->key() == Qt::Key_Escape) {
-                emit closeClicked();
-                return true;
-            }
+    QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+    if (keyEvent->key() == Qt::Key_Escape) {
+        emit closeClicked();
+        return true;
+    }
 
-            if (keyEvent->key() == Qt::Key_Return && !keyEvent->modifiers()) {
-                _findNextButton->click();
-                return true;
-            }
+    if (keyEvent->key() == Qt::Key_Return && !keyEvent->modifiers()) {
+        _findNextButton->click();
+        return true;
+    }
 
-            if ((keyEvent->key() == Qt::Key_Return)
-                && (keyEvent->modifiers() == Qt::ShiftModifier)) {
-                _findPreviousButton->click();
-                return true;
-            }
+    if ((keyEvent->key() == Qt::Key_Return)
+        && (keyEvent->modifiers() == Qt::ShiftModifier)) {
+        _findPreviousButton->click();
+        return true;
+    }
 
-            if ((keyEvent->key() == Qt::Key_Return)
-                && (keyEvent->modifiers() == Qt::ControlModifier)) {
-                _searchFromButton->click();
-                return true;
-            }
-        }
+    if ((keyEvent->key() == Qt::Key_Return)
+        && (keyEvent->modifiers() == Qt::ControlModifier)) {
+        _searchFromButton->click();
+        return true;
     }
 
     return QWidget::eventFilter(watched, event);
 }
 
+void IncrementalSearchBar::correctPosition(const QSize &parentSize)
+{
+    const auto width = geometry().width();
+    const auto height = geometry().height();
+    const auto x = parentSize.width() - width;
+    setGeometry(x, 0, width, height);
+}
+
 void IncrementalSearchBar::keyPressEvent(QKeyEvent *event)
 {
-    static QSet<int> movementKeysToPassAlong = QSet<int>()
-                                               << Qt::Key_PageUp
-                                               << Qt::Key_PageDown
-                                               << Qt::Key_Up
-                                               << Qt::Key_Down;
+    static auto movementKeysToPassAlong = QSet<int>{
+        Qt::Key_PageUp, Qt::Key_PageDown, Qt::Key_Up, Qt::Key_Down
+    };
 
     if (movementKeysToPassAlong.contains(event->key())
         && (event->modifiers() == Qt::ShiftModifier)) {
         emit unhandledMovementKeyPressed(event);
-    } else {
-        QWidget::keyPressEvent(event);
     }
 }
 
@@ -252,23 +267,18 @@ void IncrementalSearchBar::setVisible(bool visible)
 
 void IncrementalSearchBar::setFoundMatch(bool match)
 {
-    if (!match && !_searchEdit->text().isEmpty()) {
-        KStatefulBrush backgroundBrush(KColorScheme::View, KColorScheme::NegativeBackground);
-
-        QString matchStyleSheet = QStringLiteral("QLineEdit{ background-color:%1 }")
-                                  .arg(backgroundBrush.brush(_searchEdit).color().name());
-
-        _searchEdit->setStyleSheet(matchStyleSheet);
-    } else if (_searchEdit->text().isEmpty()) {
-        clearLineEdit();
-    } else {
-        KStatefulBrush backgroundBrush(KColorScheme::View, KColorScheme::PositiveBackground);
-
-        QString matchStyleSheet = QStringLiteral("QLineEdit{ background-color:%1 }")
-                                  .arg(backgroundBrush.brush(_searchEdit).color().name());
-
-        _searchEdit->setStyleSheet(matchStyleSheet);
+    if (_searchEdit->text().isEmpty()) {
+         clearLineEdit();
+         return;
     }
+
+    const auto backgroundBrush = KStatefulBrush(KColorScheme::View,
+        match ? KColorScheme::PositiveBackground : KColorScheme::NegativeBackground);
+
+    const auto matchStyleSheet = QStringLiteral("QLineEdit{ background-color:%1 }")
+                              .arg(backgroundBrush.brush(_searchEdit).color().name());
+
+    _searchEdit->setStyleSheet(matchStyleSheet);
 }
 
 void IncrementalSearchBar::clearLineEdit()
@@ -285,43 +295,17 @@ void IncrementalSearchBar::focusLineEdit()
 const QBitArray IncrementalSearchBar::optionsChecked()
 {
     QBitArray options(4, false);
-
-    if (_caseSensitive->isChecked()) {
-        options.setBit(MatchCase);
-    }
-    if (_regExpression->isChecked()) {
-        options.setBit(RegExp);
-    }
-    if (_highlightMatches->isChecked()) {
-        options.setBit(HighlightMatches);
-    }
-    if (_reverseSearch->isChecked()) {
-        options.setBit(ReverseSearch);
-    }
-
+    options.setBit(MatchCase, _caseSensitive->isChecked());
+    options.setBit(RegExp, _regExpression->isChecked());
+    options.setBit(HighlightMatches, _highlightMatches->isChecked());
+    options.setBit(ReverseSearch, _reverseSearch->isChecked());
     return options;
 }
 
 void IncrementalSearchBar::setOptions()
 {
-    if (KonsoleSettings::searchCaseSensitive()) {
-        _caseSensitive->setChecked(true);
-    } else {
-        _caseSensitive->setChecked(false);
-    }
-    if (KonsoleSettings::searchRegExpression()) {
-        _regExpression->setChecked(true);
-    } else {
-        _regExpression->setChecked(false);
-    }
-    if (KonsoleSettings::searchHighlightMatches()) {
-        _highlightMatches->setChecked(true);
-    } else {
-        _highlightMatches->setChecked(false);
-    }
-    if (KonsoleSettings::searchReverseSearch()) {
-        _reverseSearch->setChecked(true);
-    } else {
-        _reverseSearch->setChecked(false);
-    }
+    _caseSensitive->setChecked(KonsoleSettings::searchCaseSensitive());
+    _regExpression->setChecked(KonsoleSettings::searchRegExpression());
+    _highlightMatches->setChecked(KonsoleSettings::searchHighlightMatches());
+    _reverseSearch->setChecked(KonsoleSettings::searchReverseSearch());
 }
