@@ -684,7 +684,7 @@ void Screen::checkSelection(int from, int to)
     }
 }
 
-void Screen::displayCharacter(uint c)
+void Screen::displayCharacter(unsigned short c)
 {
     // Note that VT100 does wrapping BEFORE putting the character.
     // This has impact on the assumption of valid cursor positions.
@@ -697,8 +697,8 @@ void Screen::displayCharacter(uint c)
         // Non-printable character
         return;
     } else if (w == 0) {
-        const QChar::Category category = QChar::category(c);
-        if (category != QChar::Mark_NonSpacing && category != QChar::Letter_Other) {
+        const QChar::Category category = QChar(c).category();
+        if (category != QChar::Mark_NonSpacing && category != QChar::Letter_Other && !QChar::isLowSurrogate(c)) {
             return;
         }
         // Find previous "real character" to try to combine with
@@ -723,18 +723,18 @@ void Screen::displayCharacter(uint c)
 
         Character& currentChar = _screenLines[charToCombineWithY][charToCombineWithX];
         if ((currentChar.rendition & RE_EXTENDED_CHAR) == 0) {
-            const uint chars[2] = { currentChar.character, c };
+            const ushort chars[2] = { currentChar.character, c };
             currentChar.rendition |= RE_EXTENDED_CHAR;
             currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars, 2);
         } else {
             ushort extendedCharLength;
-            const uint* oldChars = ExtendedCharTable::instance.lookupExtendedChar(currentChar.character, extendedCharLength);
+            const ushort* oldChars = ExtendedCharTable::instance.lookupExtendedChar(currentChar.character, extendedCharLength);
             Q_ASSERT(oldChars);
             if (((oldChars) != nullptr) && extendedCharLength < 3) {
                 Q_ASSERT(extendedCharLength > 1);
                 Q_ASSERT(extendedCharLength < 65535);
-                auto chars = new uint[extendedCharLength + 1];
-                memcpy(chars, oldChars, sizeof(uint) * extendedCharLength);
+                auto chars = new ushort[extendedCharLength + 1];
+                memcpy(chars, oldChars, sizeof(ushort) * extendedCharLength);
                 chars[extendedCharLength] = c;
                 currentChar.character = ExtendedCharTable::instance.createExtendedChar(chars, extendedCharLength + 1);
                 delete[] chars;
@@ -928,7 +928,7 @@ void Screen::clearImage(int loca, int loce, char c)
     const int topLine = loca / _columns;
     const int bottomLine = loce / _columns;
 
-    Character clearCh(uint(c), _currentForeground, _currentBackground, DEFAULT_RENDITION, false);
+    Character clearCh(c, _currentForeground, _currentBackground, DEFAULT_RENDITION, false);
 
     //if the character being used to clear the area is the same as the
     //default character, the affected _lines can simply be shrunk.
@@ -1093,7 +1093,7 @@ void Screen::setDefaultRendition()
 
 void Screen::setForeColor(int space, int color)
 {
-    _currentForeground = CharacterColor(quint8(space), color);
+    _currentForeground = CharacterColor(space, color);
 
     if (_currentForeground.isValid()) {
         updateEffectiveRendition();
@@ -1104,7 +1104,7 @@ void Screen::setForeColor(int space, int color)
 
 void Screen::setBackColor(int space, int color)
 {
-    _currentBackground = CharacterColor(quint8(space), color);
+    _currentBackground = CharacterColor(space, color);
 
     if (_currentBackground.isValid()) {
         updateEffectiveRendition();
